California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 35 - PUBLIC WORKS PROJECTS. USE OF PRIVATE CONTRACTORS FOR ENGINEERING AND ARCHITECTURAL SERVICES. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990274 | TAXPAYERS FOR FAIR COMPETITION / YES ON PROP. 35 - A COALITION OF TAXPAYERS, ENGINEERS, SENIORS, SCHOOLS, LOCAL GOVERNMENT, BUSINESS, LABOR, HIGHWAY SAFETY EXPERTS AND FRUSTRATED COMMUTERS. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990761 | NO ON PROP. 35 - A COALITION OF ENGINEERS, PEACE OFFICERS, FIREFIGHTERS, TAXPAYERS, PUBLIC SERVANTS, SMALL BUSINESSES, TEACHERS AND SENIOR CITIZENS. | OPPOSE